**-- ! under construction ! --**

# humancenteredTSA
human centered TimeSeries Analysis

## Project Page

https://andreseku.github.io/humancenteredTSA/

## Project Structure
- hctsa: core folders and files
- app.py, a flask server with a REST API for using the pipeline
- - pipeline for creating and running the pipeline
- - descriptive timeseries analysis
- - preparation of timeseries data
- - visualizations and explainability
- - exception handling

## Dependencies
- pandas
- math
- matplotlib
- seaborn
- flask
- flask_cors
